@@ -23,10 +23,8 @@ from email.mime.text import MIMEText
 import telepot
 from PyQt5.QtWidgets import QWidget, QVBoxLayout, QPushButton, QHBoxLayout
 from PyQt5.QtCore import pyqtSlot, pyqtSignal
-from transphire.notificationwidget import NotificationWidget
-from transphire.emaildialog import EmailDialog
-from transphire import transphire_utils as tu
 
+from . import transphire_utils as tu
 
 class NotificationContainer(QWidget):
     """
@@ -610,3 +608,6 @@ class NotificationContainer(QWidget):
                 name,
                 err
                 ))
+
+from .notificationwidget import NotificationWidget
+from .emaildialog import EmailDialog
