@@ -32,7 +32,8 @@ from matplotlib.backends.backend_qt5agg import (
     FigureCanvasQTAgg as FigureCanvas,
     NavigationToolbar2QT as NavigationToolbar
     )
-from transphire import transphire_utils as tu
+
+from . import transphire_utils as tu
 warnings.filterwarnings('ignore')
 
 LIGHTRED = '#ff726f'
