@@ -19,7 +19,8 @@ import json
 import os
 import imageio
 import numpy as np
-from transphire import transphire_utils as tu
+
+from . import transphire_utils as tu
 
 
 def get_picking_command(file_input, new_name, settings, queue_com, name):
